#! /bin/bash

DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

mkdir -p test
mkdir -p gold
mkdir -p out

# training data (50000 sentences)
~/toolbox/create_prefixes_virtual_unified.py -pd -l de  ~/../hamburg-dependency-treebank/heiseticker/heiseticker-s%i.cda train/%s-%i.conll 1 50000

# training data with nonspec
mkdir -p train-nonspec
~/toolbox/create_prefixes_virtual_unified.py -n -l de  ~/../hamburg-dependency-treebank/heiseticker/heiseticker-s%i.cda train-nonspec/%s-%i.conll 1 50000

# gold standard:
~/toolbox/create_prefixes_virtual_unified.py -d -l de  ~/../hamburg-dependency-treebank/heiseticker/heiseticker-s%i.cda gold/%s-%i.conll 100001 101000

# input for TurboParser: fixed set of VNs
~/toolbox/create_prefixes_virtual_unified.py -ps -l de  ~/../hamburg-dependency-treebank/heiseticker/heiseticker-s%i.cda test/%s-%i.conll 100001 101000


mkdir -p gold-nonspec
~/toolbox/create_prefixes_virtual_unified.py -n -l de  ~/../hamburg-dependency-treebank/heiseticker/heiseticker-s%i.cda gold-nonspec/%s-%i.conll 100001 101000

#########
# nonspec

#train
~/TurboParser/src/parser/TurboParser -file_model heise-incr-1-50000-nonspec.model -train -file_train train-nonspec -logtostderr

mkdir -p out-nonspec
~/TurboParser/src/parser/TurboParser -file_model heise-incr-1-50000-nonspec.model -test -file_test gold-nonspec -file_prediction out-nonspec -logtostderr

cd out-nonspec
ls | xargs sed -i 's/\t0\t_/\t0\t\t/'
cd ..

~/toolbox/cdgevaluator_timecourse.py  out/heiseticker-s%id-%incr.conll gold/heiseticker-s%id-%incr.conll 100001 101000 5 > hdt-1-50000-minpred.data
~/toolbox/cdgevaluator_timecourse.py  out-nonspec/heiseticker-s%id-%incr.conll gold/heiseticker-s%id-%incr.conll 100001 101000 5 > hdt-1-50000-nonspec.data


# end nonspec
#############

#########
# nonincr
#########
~/TurboParser/src/parser/TurboParser -file_model heise-1-50000-nonincr.model -train -file_train heiseticker-1-50000-conll -logtostderr

~/TurboParser/src/parser/TurboParser -file_model heise-1-50000-nonincr.model -test -file_test gold-nonspec -file_prediction out-nonincr -logtostderr
cd out-nonincr
ls | xargs sed -i 's/\t0\tROOT/\t0\t\t/'
cd ..

~/toolbox/cdgevaluator_timecourse.py out-nonincr/heiseticker-s%id-%incr.conll gold-nonspec/heiseticker-s%id-%incr.conll 100001 101000 5 > hdt-nonincr.data


# FIXME this is a hack because TurboParser emits "ROOT" instead of "" for empty labels
cd out
ls | xargs sed -i 's/\t0\tROOT/\t0\t\t/'
cd ..

#####
# create training for TP with tagged data
#####
# really sad, but I have not enough time for 50k:-(
mkdir train-1-10000
~/toolbox/create_prefixes_virtual_unified.py -pd -l de  ~/../hamburg-dependency-treebank/heiseticker/heiseticker-s%i.cda train-1-10000/%s-%i.conll 1 10000

mkdir -p train-1-10000-tagged
for f in $(find train-1-10000 -type f); do ~/TurboParser/src/tagger/TurboTagger -file_model tagger-1-50000.model -file_test <(awk '{ if (NF>0) print $2 "\t" $5; else print ""}' $f) -file_prediction train-1-10000-tagged${f#train-1-10000} -logtostderr -test; done

mkdir -p train-1-10000-tagged-conll
for f in $(find train-1-10000-tagged -type f); do ~/toolbox/tagger2conll.py < $f > train-1-10000-tagged-conll${f#train-1-10000-tagged}; done

mkdir -p train-1-10000-tagged-merged
for i in $(ls train-1-10000-tagged); do awk -F '\t' 'FNR==NR{a[$1]=$4 FS $5;next}{ print $1 FS $2 FS $3 FS a[$1] FS $6 FS $7 FS $8}'  train-1-10000-tagged-conll/$i train-1-10000/$i > train-1-10000-tagged-merged/$i; done

~/TurboParser/src/parser/TurboParser -file_model heise-incr-1-50000-tagged.model -train -file_train train-1-10000-tagged-merged -logtostderr


##### done

~/toolbox/cdgevaluator_timecourse.py -su out/heiseticker-s%id-%incr.conll gold/heiseticker-s%id-%incr.conll 100001 101000 5 > turbo-result


# tagger
mkdir -p tagger-train
~/toolbox/create_prefixes_virtual_unified.py -ps -l de  ~/../hamburg-dependency-treebank/heiseticker/heiseticker-s%i.cda tagger-train/%s-%i.conll 1 50000

# collect everything in one file for training
find tagger-train/ -type f | xargs -n 1 -- gawk -F "\t" '{ if (NF>0) print $2 "\t" $5; else print ""}; END {print ""}' > tagger-trainfile.conll

~/TurboParser/src/tagger/TurboTagger -train -file_train tagger-trainfile.conll -file_model tagger-1-50000.model -logtostderr

# create tagged test data for TurboParser
mkdir -p test-tagged

for f in $(find test -type f); do ~/TurboParser/src/tagger/TurboTagger -file_model tagger-1-50000.model -file_test <(awk '{ if (NF>0) print $2 "\t" $5; else print ""}' $f) -file_prediction test-tagged${f#test} -logtostderr -test; done

mkdir -p test-tagged-conll

for f in $(find test-tagged -type f); do ~/toolbox/tagger2conll.py < $f > test-tagged-conll${f#test-tagged}; done

# maybe? find test-tagged-conll -type f | xargs sed -i $'s/_\t_\t_\t_\t_/_\t0\tS\t_\t_/'

# insert lost virtual markers
# find test-tagged-conll/ -type f | xargs sed -i $'/\[virtual\]\|\[unused\]/ s/\(VIRT\|ZZZNOWORD\)\t_/VIRT\tvirtual/'

# merge with original test set
for i in $(ls test); do awk -F '\t' 'FNR==NR{a[$1]=$4 FS $5;next}{ print $1 FS $2 FS $3 FS a[$1] FS $6 FS $7 FS $8}'  test-tagged-conll/$i test/$i > test-tagged-conll2/$i; done

# replace wrong tag
#find test-tagged-conll2/ -type f | xargs sed -i $'s/ZZZNOWORD\tVIRT/ZZZNOWORD\tZZZNOWORD/'

# run TurboParser on tagged data
mkdir -p out-tagged
~/TurboParser/src/parser/TurboParser -file_model heise-incr-1-50000.model -test -file_test test-tagged-conll/ -file_prediction out-tagged/ -logtostderr
~/toolbox/cdgevaluator_timecourse.py -su out-tagged/heiseticker-s%id-%incr.conll gold/heiseticker-s%id-%incr.conll 100001 101000 5 > hdt-1-50000-tagged-structural.data
